webriskpb

package
v1.16.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: Apache-2.0 Imports: 12 Imported by: 2

Documentation

Index

Constants

const (
	WebRiskService_ComputeThreatListDiff_FullMethodName = "/google.cloud.webrisk.v1.WebRiskService/ComputeThreatListDiff"
	WebRiskService_SearchUris_FullMethodName            = "/google.cloud.webrisk.v1.WebRiskService/SearchUris"
	WebRiskService_SearchHashes_FullMethodName          = "/google.cloud.webrisk.v1.WebRiskService/SearchHashes"
	WebRiskService_CreateSubmission_FullMethodName      = "/google.cloud.webrisk.v1.WebRiskService/CreateSubmission"
	WebRiskService_SubmitUri_FullMethodName             = "/google.cloud.webrisk.v1.WebRiskService/SubmitUri"
)

Variables

var (
	ThreatType_name = map[int32]string{
		0: "THREAT_TYPE_UNSPECIFIED",
		1: "MALWARE",
		2: "SOCIAL_ENGINEERING",
		3: "UNWANTED_SOFTWARE",
		4: "SOCIAL_ENGINEERING_EXTENDED_COVERAGE",
	}
	ThreatType_value = map[string]int32{
		"THREAT_TYPE_UNSPECIFIED":              0,
		"MALWARE":                              1,
		"SOCIAL_ENGINEERING":                   2,
		"UNWANTED_SOFTWARE":                    3,
		"SOCIAL_ENGINEERING_EXTENDED_COVERAGE": 4,
	}
)

Enum value maps for ThreatType.

var (
	CompressionType_name = map[int32]string{
		0: "COMPRESSION_TYPE_UNSPECIFIED",
		1: "RAW",
		2: "RICE",
	}
	CompressionType_value = map[string]int32{
		"COMPRESSION_TYPE_UNSPECIFIED": 0,
		"RAW":                          1,
		"RICE":                         2,
	}
)

Enum value maps for CompressionType.

var (
	ComputeThreatListDiffResponse_ResponseType_name = map[int32]string{
		0: "RESPONSE_TYPE_UNSPECIFIED",
		1: "DIFF",
		2: "RESET",
	}
	ComputeThreatListDiffResponse_ResponseType_value = map[string]int32{
		"RESPONSE_TYPE_UNSPECIFIED": 0,
		"DIFF":                      1,
		"RESET":                     2,
	}
)

Enum value maps for ComputeThreatListDiffResponse_ResponseType.

var (
	ThreatInfo_AbuseType_name = map[int32]string{
		0: "ABUSE_TYPE_UNSPECIFIED",
		1: "MALWARE",
		2: "SOCIAL_ENGINEERING",
		3: "UNWANTED_SOFTWARE",
	}
	ThreatInfo_AbuseType_value = map[string]int32{
		"ABUSE_TYPE_UNSPECIFIED": 0,
		"MALWARE":                1,
		"SOCIAL_ENGINEERING":     2,
		"UNWANTED_SOFTWARE":      3,
	}
)

Enum value maps for ThreatInfo_AbuseType.

var (
	ThreatInfo_Confidence_ConfidenceLevel_name = map[int32]string{
		0: "CONFIDENCE_LEVEL_UNSPECIFIED",
		1: "LOW",
		2: "MEDIUM",
		3: "HIGH",
	}
	ThreatInfo_Confidence_ConfidenceLevel_value = map[string]int32{
		"CONFIDENCE_LEVEL_UNSPECIFIED": 0,
		"LOW":                          1,
		"MEDIUM":                       2,
		"HIGH":                         3,
	}
)

Enum value maps for ThreatInfo_Confidence_ConfidenceLevel.

var (
	ThreatInfo_ThreatJustification_JustificationLabel_name = map[int32]string{
		0: "JUSTIFICATION_LABEL_UNSPECIFIED",
		1: "MANUAL_VERIFICATION",
		2: "USER_REPORT",
		3: "AUTOMATED_REPORT",
	}
	ThreatInfo_ThreatJustification_JustificationLabel_value = map[string]int32{
		"JUSTIFICATION_LABEL_UNSPECIFIED": 0,
		"MANUAL_VERIFICATION":             1,
		"USER_REPORT":                     2,
		"AUTOMATED_REPORT":                3,
	}
)

Enum value maps for ThreatInfo_ThreatJustification_JustificationLabel.

var (
	ThreatDiscovery_Platform_name = map[int32]string{
		0: "PLATFORM_UNSPECIFIED",
		1: "ANDROID",
		2: "IOS",
		3: "MACOS",
		4: "WINDOWS",
	}
	ThreatDiscovery_Platform_value = map[string]int32{
		"PLATFORM_UNSPECIFIED": 0,
		"ANDROID":              1,
		"IOS":                  2,
		"MACOS":                3,
		"WINDOWS":              4,
	}
)

Enum value maps for ThreatDiscovery_Platform.

var (
	SubmitUriMetadata_State_name = map[int32]string{
		0: "STATE_UNSPECIFIED",
		1: "RUNNING",
		2: "SUCCEEDED",
		3: "CANCELLED",
		4: "FAILED",
		5: "CLOSED",
	}
	SubmitUriMetadata_State_value = map[string]int32{
		"STATE_UNSPECIFIED": 0,
		"RUNNING":           1,
		"SUCCEEDED":         2,
		"CANCELLED":         3,
		"FAILED":            4,
		"CLOSED":            5,
	}
)

Enum value maps for SubmitUriMetadata_State.

var File_google_cloud_webrisk_v1_webrisk_proto protoreflect.FileDescriptor
var WebRiskService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "google.cloud.webrisk.v1.WebRiskService",
	HandlerType: (*WebRiskServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ComputeThreatListDiff",
			Handler:    _WebRiskService_ComputeThreatListDiff_Handler,
		},
		{
			MethodName: "SearchUris",
			Handler:    _WebRiskService_SearchUris_Handler,
		},
		{
			MethodName: "SearchHashes",
			Handler:    _WebRiskService_SearchHashes_Handler,
		},
		{
			MethodName: "CreateSubmission",
			Handler:    _WebRiskService_CreateSubmission_Handler,
		},
		{
			MethodName: "SubmitUri",
			Handler:    _WebRiskService_SubmitUri_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/cloud/webrisk/v1/webrisk.proto",
}

WebRiskService_ServiceDesc is the grpc.ServiceDesc for WebRiskService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterWebRiskServiceServer

func RegisterWebRiskServiceServer(s grpc.ServiceRegistrar, srv WebRiskServiceServer)

Types

type CompressionType

type CompressionType int32

The ways in which threat entry sets can be compressed.

const (
	// Unknown.
	CompressionType_COMPRESSION_TYPE_UNSPECIFIED CompressionType = 0
	// Raw, uncompressed data.
	CompressionType_RAW CompressionType = 1
	// Rice-Golomb encoded data.
	CompressionType_RICE CompressionType = 2
)

func (CompressionType) Descriptor

func (CompressionType) Enum

func (x CompressionType) Enum() *CompressionType

func (CompressionType) EnumDescriptor deprecated

func (CompressionType) EnumDescriptor() ([]byte, []int)

Deprecated: Use CompressionType.Descriptor instead.

func (CompressionType) Number

func (CompressionType) String

func (x CompressionType) String() string

func (CompressionType) Type

type ComputeThreatListDiffRequest

type ComputeThreatListDiffRequest struct {

	// Required. The threat list to update. Only a single ThreatType should be
	// specified per request. If you want to handle multiple ThreatTypes, you must
	// make one request per ThreatType.
	ThreatType ThreatType `` /* 132-byte string literal not displayed */
	// The current version token of the client for the requested list (the
	// client version that was received from the last successful diff).
	// If the client does not have a version token (this is the first time calling
	// ComputeThreatListDiff), this may be left empty and a full database
	// snapshot will be returned.
	VersionToken []byte `protobuf:"bytes,2,opt,name=version_token,json=versionToken,proto3" json:"version_token,omitempty"`
	// Required. The constraints associated with this request.
	Constraints *ComputeThreatListDiffRequest_Constraints `protobuf:"bytes,3,opt,name=constraints,proto3" json:"constraints,omitempty"`
	// contains filtered or unexported fields
}

Describes an API diff request.

func (*ComputeThreatListDiffRequest) Descriptor deprecated

func (*ComputeThreatListDiffRequest) Descriptor() ([]byte, []int)

Deprecated: Use ComputeThreatListDiffRequest.ProtoReflect.Descriptor instead.

func (*ComputeThreatListDiffRequest) GetConstraints

func (*ComputeThreatListDiffRequest) GetThreatType

func (x *ComputeThreatListDiffRequest) GetThreatType() ThreatType

func (*ComputeThreatListDiffRequest) GetVersionToken

func (x *ComputeThreatListDiffRequest) GetVersionToken() []byte

func (*ComputeThreatListDiffRequest) ProtoMessage

func (*ComputeThreatListDiffRequest) ProtoMessage()

func (*ComputeThreatListDiffRequest) ProtoReflect

func (*ComputeThreatListDiffRequest) Reset

func (x *ComputeThreatListDiffRequest) Reset()

func (*ComputeThreatListDiffRequest) String

type ComputeThreatListDiffRequest_Constraints

type ComputeThreatListDiffRequest_Constraints struct {

	// The maximum size in number of entries. The diff will not contain more
	// entries than this value.  This should be a power of 2 between 2**10 and
	// 2**20.  If zero, no diff size limit is set.
	MaxDiffEntries int32 `protobuf:"varint,1,opt,name=max_diff_entries,json=maxDiffEntries,proto3" json:"max_diff_entries,omitempty"`
	// Sets the maximum number of entries that the client is willing to have
	// in the local database. This should be a power of 2 between 2**10 and
	// 2**20. If zero, no database size limit is set.
	MaxDatabaseEntries int32 `protobuf:"varint,2,opt,name=max_database_entries,json=maxDatabaseEntries,proto3" json:"max_database_entries,omitempty"`
	// The compression types supported by the client.
	SupportedCompressions []CompressionType `` /* 177-byte string literal not displayed */
	// contains filtered or unexported fields
}

The constraints for this diff.

func (*ComputeThreatListDiffRequest_Constraints) Descriptor deprecated

func (*ComputeThreatListDiffRequest_Constraints) Descriptor() ([]byte, []int)

Deprecated: Use ComputeThreatListDiffRequest_Constraints.ProtoReflect.Descriptor instead.

func (*ComputeThreatListDiffRequest_Constraints) GetMaxDatabaseEntries

func (x *ComputeThreatListDiffRequest_Constraints) GetMaxDatabaseEntries() int32

func (*ComputeThreatListDiffRequest_Constraints) GetMaxDiffEntries

func (x *ComputeThreatListDiffRequest_Constraints) GetMaxDiffEntries() int32

func (*ComputeThreatListDiffRequest_Constraints) GetSupportedCompressions

func (x *ComputeThreatListDiffRequest_Constraints) GetSupportedCompressions() []CompressionType

func (*ComputeThreatListDiffRequest_Constraints) ProtoMessage

func (*ComputeThreatListDiffRequest_Constraints) ProtoReflect

func (*ComputeThreatListDiffRequest_Constraints) Reset

func (*ComputeThreatListDiffRequest_Constraints) String

type ComputeThreatListDiffResponse

type ComputeThreatListDiffResponse struct {

	// The type of response. This may indicate that an action must be taken by the
	// client when the response is received.
	ResponseType ComputeThreatListDiffResponse_ResponseType `` /* 170-byte string literal not displayed */
	// A set of entries to add to a local threat type's list.
	Additions *ThreatEntryAdditions `protobuf:"bytes,5,opt,name=additions,proto3" json:"additions,omitempty"`
	// A set of entries to remove from a local threat type's list.
	// This field may be empty.
	Removals *ThreatEntryRemovals `protobuf:"bytes,6,opt,name=removals,proto3" json:"removals,omitempty"`
	// The new opaque client version token. This should be retained by the client
	// and passed into the next call of ComputeThreatListDiff as 'version_token'.
	// A separate version token should be stored and used for each threatList.
	NewVersionToken []byte `protobuf:"bytes,7,opt,name=new_version_token,json=newVersionToken,proto3" json:"new_version_token,omitempty"`
	// The expected SHA256 hash of the client state; that is, of the sorted list
	// of all hashes present in the database after applying the provided diff.
	// If the client state doesn't match the expected state, the client must
	// discard this diff and retry later.
	Checksum *ComputeThreatListDiffResponse_Checksum `protobuf:"bytes,8,opt,name=checksum,proto3" json:"checksum,omitempty"`
	// The soonest the client should wait before issuing any diff
	// request. Querying sooner is unlikely to produce a meaningful diff.
	// Waiting longer is acceptable considering the use case.
	// If this field is not set clients may update as soon as they want.
	RecommendedNextDiff *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=recommended_next_diff,json=recommendedNextDiff,proto3" json:"recommended_next_diff,omitempty"`
	// contains filtered or unexported fields
}

func (*ComputeThreatListDiffResponse) Descriptor deprecated

func (*ComputeThreatListDiffResponse) Descriptor() ([]byte, []int)

Deprecated: Use ComputeThreatListDiffResponse.ProtoReflect.Descriptor instead.

func (*ComputeThreatListDiffResponse) GetAdditions

func (*ComputeThreatListDiffResponse) GetChecksum

func (*ComputeThreatListDiffResponse) GetNewVersionToken

func (x *ComputeThreatListDiffResponse) GetNewVersionToken() []byte

func (*ComputeThreatListDiffResponse) GetRecommendedNextDiff

func (x *ComputeThreatListDiffResponse) GetRecommendedNextDiff() *timestamppb.Timestamp

func (*ComputeThreatListDiffResponse) GetRemovals

func (*ComputeThreatListDiffResponse) GetResponseType

func (*ComputeThreatListDiffResponse) ProtoMessage

func (*ComputeThreatListDiffResponse) ProtoMessage()

func (*ComputeThreatListDiffResponse) ProtoReflect

func (*ComputeThreatListDiffResponse) Reset

func (x *ComputeThreatListDiffResponse) Reset()

func (*ComputeThreatListDiffResponse) String

type ComputeThreatListDiffResponse_Checksum

type ComputeThreatListDiffResponse_Checksum struct {

	// The SHA256 hash of the client state; that is, of the sorted list of all
	// hashes present in the database.
	Sha256 []byte `protobuf:"bytes,1,opt,name=sha256,proto3" json:"sha256,omitempty"`
	// contains filtered or unexported fields
}

The expected state of a client's local database.

func (*ComputeThreatListDiffResponse_Checksum) Descriptor deprecated

func (*ComputeThreatListDiffResponse_Checksum) Descriptor() ([]byte, []int)

Deprecated: Use ComputeThreatListDiffResponse_Checksum.ProtoReflect.Descriptor instead.

func (*ComputeThreatListDiffResponse_Checksum) GetSha256

func (*ComputeThreatListDiffResponse_Checksum) ProtoMessage

func (*ComputeThreatListDiffResponse_Checksum) ProtoReflect

func (*ComputeThreatListDiffResponse_Checksum) Reset

func (*ComputeThreatListDiffResponse_Checksum) String

type ComputeThreatListDiffResponse_ResponseType

type ComputeThreatListDiffResponse_ResponseType int32

The type of response sent to the client.

const (
	// Unknown.
	ComputeThreatListDiffResponse_RESPONSE_TYPE_UNSPECIFIED ComputeThreatListDiffResponse_ResponseType = 0
	// Partial updates are applied to the client's existing local database.
	ComputeThreatListDiffResponse_DIFF ComputeThreatListDiffResponse_ResponseType = 1
	// Full updates resets the client's entire local database. This means
	// that either the client had no state, was seriously out-of-date,
	// or the client is believed to be corrupt.
	ComputeThreatListDiffResponse_RESET ComputeThreatListDiffResponse_ResponseType = 2
)

func (ComputeThreatListDiffResponse_ResponseType) Descriptor

func (ComputeThreatListDiffResponse_ResponseType) Enum

func (ComputeThreatListDiffResponse_ResponseType) EnumDescriptor deprecated

func (ComputeThreatListDiffResponse_ResponseType) EnumDescriptor() ([]byte, []int)

Deprecated: Use ComputeThreatListDiffResponse_ResponseType.Descriptor instead.

func (ComputeThreatListDiffResponse_ResponseType) Number

func (ComputeThreatListDiffResponse_ResponseType) String

func (ComputeThreatListDiffResponse_ResponseType) Type

type CreateSubmissionRequest

type CreateSubmissionRequest struct {

	// Required. The name of the project that is making the submission. This
	// string is in the format "projects/{project_number}".
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Required. The submission that contains the content of the phishing report.
	Submission *Submission `protobuf:"bytes,2,opt,name=submission,proto3" json:"submission,omitempty"`
	// contains filtered or unexported fields
}

Request to send a potentially phishy URI to WebRisk.

func (*CreateSubmissionRequest) Descriptor deprecated

func (*CreateSubmissionRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateSubmissionRequest.ProtoReflect.Descriptor instead.

func (*CreateSubmissionRequest) GetParent

func (x *CreateSubmissionRequest) GetParent() string

func (*CreateSubmissionRequest) GetSubmission

func (x *CreateSubmissionRequest) GetSubmission() *Submission

func (*CreateSubmissionRequest) ProtoMessage

func (*CreateSubmissionRequest) ProtoMessage()

func (*CreateSubmissionRequest) ProtoReflect

func (x *CreateSubmissionRequest) ProtoReflect() protoreflect.Message

func (*CreateSubmissionRequest) Reset

func (x *CreateSubmissionRequest) Reset()

func (*CreateSubmissionRequest) String

func (x *CreateSubmissionRequest) String() string

type RawHashes

type RawHashes struct {

	// The number of bytes for each prefix encoded below.  This field can be
	// anywhere from 4 (shortest prefix) to 32 (full SHA256 hash).
	// In practice this is almost always 4, except in exceptional circumstances.
	PrefixSize int32 `protobuf:"varint,1,opt,name=prefix_size,json=prefixSize,proto3" json:"prefix_size,omitempty"`
	// The hashes, in binary format, concatenated into one long string. Hashes are
	// sorted in lexicographic order. For JSON API users, hashes are
	// base64-encoded.
	RawHashes []byte `protobuf:"bytes,2,opt,name=raw_hashes,json=rawHashes,proto3" json:"raw_hashes,omitempty"`
	// contains filtered or unexported fields
}

The uncompressed threat entries in hash format. Hashes can be anywhere from 4 to 32 bytes in size. A large majority are 4 bytes, but some hashes are lengthened if they collide with the hash of a popular URI.

Used for sending ThreatEntryAdditons to clients that do not support compression, or when sending non-4-byte hashes to clients that do support compression.

func (*RawHashes) Descriptor deprecated

func (*RawHashes) Descriptor() ([]byte, []int)

Deprecated: Use RawHashes.ProtoReflect.Descriptor instead.

func (*RawHashes) GetPrefixSize

func (x *RawHashes) GetPrefixSize() int32

func (*RawHashes) GetRawHashes

func (x *RawHashes) GetRawHashes() []byte

func (*RawHashes) ProtoMessage

func (*RawHashes) ProtoMessage()

func (*RawHashes) ProtoReflect

func (x *RawHashes) ProtoReflect() protoreflect.Message

func (*RawHashes) Reset

func (x *RawHashes) Reset()

func (*RawHashes) String

func (x *RawHashes) String() string

type RawIndices

type RawIndices struct {

	// The indices to remove from a lexicographically-sorted local list.
	Indices []int32 `protobuf:"varint,1,rep,packed,name=indices,proto3" json:"indices,omitempty"`
	// contains filtered or unexported fields
}

A set of raw indices to remove from a local list.

func (*RawIndices) Descriptor deprecated

func (*RawIndices) Descriptor() ([]byte, []int)

Deprecated: Use RawIndices.ProtoReflect.Descriptor instead.

func (*RawIndices) GetIndices

func (x *RawIndices) GetIndices() []int32

func (*RawIndices) ProtoMessage

func (*RawIndices) ProtoMessage()

func (*RawIndices) ProtoReflect

func (x *RawIndices) ProtoReflect() protoreflect.Message

func (*RawIndices) Reset

func (x *RawIndices) Reset()

func (*RawIndices) String

func (x *RawIndices) String() string

type RiceDeltaEncoding

type RiceDeltaEncoding struct {

	// The offset of the first entry in the encoded data, or, if only a single
	// integer was encoded, that single integer's value. If the field is empty or
	// missing, assume zero.
	FirstValue int64 `protobuf:"varint,1,opt,name=first_value,json=firstValue,proto3" json:"first_value,omitempty"`
	// The Golomb-Rice parameter, which is a number between 2 and 28. This field
	// is missing (that is, zero) if `num_entries` is zero.
	RiceParameter int32 `protobuf:"varint,2,opt,name=rice_parameter,json=riceParameter,proto3" json:"rice_parameter,omitempty"`
	// The number of entries that are delta encoded in the encoded data. If only a
	// single integer was encoded, this will be zero and the single value will be
	// stored in `first_value`.
	EntryCount int32 `protobuf:"varint,3,opt,name=entry_count,json=entryCount,proto3" json:"entry_count,omitempty"`
	// The encoded deltas that are encoded using the Golomb-Rice coder.
	EncodedData []byte `protobuf:"bytes,4,opt,name=encoded_data,json=encodedData,proto3" json:"encoded_data,omitempty"`
	// contains filtered or unexported fields
}

The Rice-Golomb encoded data. Used for sending compressed 4-byte hashes or compressed removal indices.

func (*RiceDeltaEncoding) Descriptor deprecated

func (*RiceDeltaEncoding) Descriptor() ([]byte, []int)

Deprecated: Use RiceDeltaEncoding.ProtoReflect.Descriptor instead.

func (*RiceDeltaEncoding) GetEncodedData

func (x *RiceDeltaEncoding) GetEncodedData() []byte

func (*RiceDeltaEncoding) GetEntryCount

func (x *RiceDeltaEncoding) GetEntryCount() int32

func (*RiceDeltaEncoding) GetFirstValue

func (x *RiceDeltaEncoding) GetFirstValue() int64

func (*RiceDeltaEncoding) GetRiceParameter

func (x *RiceDeltaEncoding) GetRiceParameter() int32

func (*RiceDeltaEncoding) ProtoMessage

func (*RiceDeltaEncoding) ProtoMessage()

func (*RiceDeltaEncoding) ProtoReflect

func (x *RiceDeltaEncoding) ProtoReflect() protoreflect.Message

func (*RiceDeltaEncoding) Reset

func (x *RiceDeltaEncoding) Reset()

func (*RiceDeltaEncoding) String

func (x *RiceDeltaEncoding) String() string

type SearchHashesRequest

type SearchHashesRequest struct {

	// A hash prefix, consisting of the most significant 4-32 bytes of a SHA256
	// hash. For JSON requests, this field is base64-encoded.
	// Note that if this parameter is provided by a URI, it must be encoded using
	// the web safe base64 variant (RFC 4648).
	HashPrefix []byte `protobuf:"bytes,1,opt,name=hash_prefix,json=hashPrefix,proto3" json:"hash_prefix,omitempty"`
	// Required. The ThreatLists to search in. Multiple ThreatLists may be
	// specified.
	ThreatTypes []ThreatType `` /* 142-byte string literal not displayed */
	// contains filtered or unexported fields
}

Request to return full hashes matched by the provided hash prefixes.

func (*SearchHashesRequest) Descriptor deprecated

func (*SearchHashesRequest) Descriptor() ([]byte, []int)

Deprecated: Use SearchHashesRequest.ProtoReflect.Descriptor instead.

func (*SearchHashesRequest) GetHashPrefix

func (x *SearchHashesRequest) GetHashPrefix() []byte

func (*SearchHashesRequest) GetThreatTypes

func (x *SearchHashesRequest) GetThreatTypes() []ThreatType

func (*SearchHashesRequest) ProtoMessage

func (*SearchHashesRequest) ProtoMessage()

func (*SearchHashesRequest) ProtoReflect

func (x *SearchHashesRequest) ProtoReflect() protoreflect.Message

func (*SearchHashesRequest) Reset

func (x *SearchHashesRequest) Reset()

func (*SearchHashesRequest) String

func (x *SearchHashesRequest) String() string

type SearchHashesResponse

type SearchHashesResponse struct {

	// The full hashes that matched the requested prefixes.
	// The hash will be populated in the key.
	Threats []*SearchHashesResponse_ThreatHash `protobuf:"bytes,1,rep,name=threats,proto3" json:"threats,omitempty"`
	// For requested entities that did not match the threat list, how long to
	// cache the response until.
	NegativeExpireTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=negative_expire_time,json=negativeExpireTime,proto3" json:"negative_expire_time,omitempty"`
	// contains filtered or unexported fields
}

func (*SearchHashesResponse) Descriptor deprecated

func (*SearchHashesResponse) Descriptor() ([]byte, []int)

Deprecated: Use SearchHashesResponse.ProtoReflect.Descriptor instead.

func (*SearchHashesResponse) GetNegativeExpireTime

func (x *SearchHashesResponse) GetNegativeExpireTime() *timestamppb.Timestamp

func (*SearchHashesResponse) GetThreats

func (*SearchHashesResponse) ProtoMessage

func (*SearchHashesResponse) ProtoMessage()

func (*SearchHashesResponse) ProtoReflect

func (x *SearchHashesResponse) ProtoReflect() protoreflect.Message

func (*SearchHashesResponse) Reset

func (x *SearchHashesResponse) Reset()

func (*SearchHashesResponse) String

func (x *SearchHashesResponse) String() string

type SearchHashesResponse_ThreatHash

type SearchHashesResponse_ThreatHash struct {

	// The ThreatList this threat belongs to.
	// This must contain at least one entry.
	ThreatTypes []ThreatType `` /* 142-byte string literal not displayed */
	// A 32 byte SHA256 hash. This field is in binary format. For JSON
	// requests, hashes are base64-encoded.
	Hash []byte `protobuf:"bytes,2,opt,name=hash,proto3" json:"hash,omitempty"`
	// The cache lifetime for the returned match. Clients must not cache this
	// response past this timestamp to avoid false positives.
	ExpireTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=expire_time,json=expireTime,proto3" json:"expire_time,omitempty"`
	// contains filtered or unexported fields
}

Contains threat information on a matching hash.

func (*SearchHashesResponse_ThreatHash) Descriptor deprecated

func (*SearchHashesResponse_ThreatHash) Descriptor() ([]byte, []int)

Deprecated: Use SearchHashesResponse_ThreatHash.ProtoReflect.Descriptor instead.

func (*SearchHashesResponse_ThreatHash) GetExpireTime

func (*SearchHashesResponse_ThreatHash) GetHash

func (x *SearchHashesResponse_ThreatHash) GetHash() []byte

func (*SearchHashesResponse_ThreatHash) GetThreatTypes

func (x *SearchHashesResponse_ThreatHash) GetThreatTypes() []ThreatType

func (*SearchHashesResponse_ThreatHash) ProtoMessage

func (*SearchHashesResponse_ThreatHash) ProtoMessage()

func (*SearchHashesResponse_ThreatHash) ProtoReflect

func (*SearchHashesResponse_ThreatHash) Reset

func (*SearchHashesResponse_ThreatHash) String

type SearchUrisRequest

type SearchUrisRequest struct {

	// Required. The URI to be checked for matches.
	Uri string `protobuf:"bytes,1,opt,name=uri,proto3" json:"uri,omitempty"`
	// Required. The ThreatLists to search in. Multiple ThreatLists may be
	// specified.
	ThreatTypes []ThreatType `` /* 142-byte string literal not displayed */
	// contains filtered or unexported fields
}

Request to check URI entries against threatLists.

func (*SearchUrisRequest) Descriptor deprecated

func (*SearchUrisRequest) Descriptor() ([]byte, []int)

Deprecated: Use SearchUrisRequest.ProtoReflect.Descriptor instead.

func (*SearchUrisRequest) GetThreatTypes

func (x *SearchUrisRequest) GetThreatTypes() []ThreatType

func (*SearchUrisRequest) GetUri

func (x *SearchUrisRequest) GetUri() string

func (*SearchUrisRequest) ProtoMessage

func (*SearchUrisRequest) ProtoMessage()

func (*SearchUrisRequest) ProtoReflect

func (x *SearchUrisRequest) ProtoReflect() protoreflect.Message

func (*SearchUrisRequest) Reset

func (x *SearchUrisRequest) Reset()

func (*SearchUrisRequest) String

func (x *SearchUrisRequest) String() string

type SearchUrisResponse

type SearchUrisResponse struct {

	// The threat list matches. This might be empty if the URI is on no list.
	Threat *SearchUrisResponse_ThreatUri `protobuf:"bytes,1,opt,name=threat,proto3" json:"threat,omitempty"`
	// contains filtered or unexported fields
}

func (*SearchUrisResponse) Descriptor deprecated

func (*SearchUrisResponse) Descriptor() ([]byte, []int)

Deprecated: Use SearchUrisResponse.ProtoReflect.Descriptor instead.

func (*SearchUrisResponse) GetThreat

func (*SearchUrisResponse) ProtoMessage

func (*SearchUrisResponse) ProtoMessage()

func (*SearchUrisResponse) ProtoReflect

func (x *SearchUrisResponse) ProtoReflect() protoreflect.Message

func (*SearchUrisResponse) Reset

func (x *SearchUrisResponse) Reset()

func (*SearchUrisResponse) String

func (x *SearchUrisResponse) String() string

type SearchUrisResponse_ThreatUri

type SearchUrisResponse_ThreatUri struct {

	// The ThreatList this threat belongs to.
	ThreatTypes []ThreatType `` /* 142-byte string literal not displayed */
	// The cache lifetime for the returned match. Clients must not cache this
	// response past this timestamp to avoid false positives.
	ExpireTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=expire_time,json=expireTime,proto3" json:"expire_time,omitempty"`
	// contains filtered or unexported fields
}

Contains threat information on a matching uri.

func (*SearchUrisResponse_ThreatUri) Descriptor deprecated

func (*SearchUrisResponse_ThreatUri) Descriptor() ([]byte, []int)

Deprecated: Use SearchUrisResponse_ThreatUri.ProtoReflect.Descriptor instead.

func (*SearchUrisResponse_ThreatUri) GetExpireTime

func (*SearchUrisResponse_ThreatUri) GetThreatTypes

func (x *SearchUrisResponse_ThreatUri) GetThreatTypes() []ThreatType

func (*SearchUrisResponse_ThreatUri) ProtoMessage

func (*SearchUrisResponse_ThreatUri) ProtoMessage()

func (*SearchUrisResponse_ThreatUri) ProtoReflect

func (*SearchUrisResponse_ThreatUri) Reset

func (x *SearchUrisResponse_ThreatUri) Reset()

func (*SearchUrisResponse_ThreatUri) String

type Submission

type Submission struct {

	// Required. The URI that is being reported for malicious content to be
	// analyzed.
	Uri string `protobuf:"bytes,1,opt,name=uri,proto3" json:"uri,omitempty"`
	// Output only. ThreatTypes found to be associated with the submitted URI
	// after reviewing it. This might be empty if the URI was not added to any
	// list.
	ThreatTypes []ThreatType `` /* 142-byte string literal not displayed */
	// contains filtered or unexported fields
}

Wraps a URI that might be displaying malicious content.

func (*Submission) Descriptor deprecated

func (*Submission) Descriptor() ([]byte, []int)

Deprecated: Use Submission.ProtoReflect.Descriptor instead.

func (*Submission) GetThreatTypes added in v1.9.0

func (x *Submission) GetThreatTypes() []ThreatType

func (*Submission) GetUri

func (x *Submission) GetUri() string

func (*Submission) ProtoMessage

func (*Submission) ProtoMessage()

func (*Submission) ProtoReflect

func (x *Submission) ProtoReflect() protoreflect.Message

func (*Submission) Reset

func (x *Submission) Reset()

func (*Submission) String

func (x *Submission) String() string

type SubmitUriMetadata added in v1.9.0

type SubmitUriMetadata struct {

	// The state of the operation.
	State SubmitUriMetadata_State `protobuf:"varint,1,opt,name=state,proto3,enum=google.cloud.webrisk.v1.SubmitUriMetadata_State" json:"state,omitempty"`
	// Creation time of the operation.
	CreateTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=create_time,json=createTime,proto3" json:"create_time,omitempty"`
	// Latest update time of the operation.
	UpdateTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=update_time,json=updateTime,proto3" json:"update_time,omitempty"`
	// contains filtered or unexported fields
}

Metadata for the Submit URI long-running operation.

func (*SubmitUriMetadata) Descriptor deprecated added in v1.9.0

func (*SubmitUriMetadata) Descriptor() ([]byte, []int)

Deprecated: Use SubmitUriMetadata.ProtoReflect.Descriptor instead.

func (*SubmitUriMetadata) GetCreateTime added in v1.9.0

func (x *SubmitUriMetadata) GetCreateTime() *timestamppb.Timestamp

func (*SubmitUriMetadata) GetState added in v1.9.0

func (*SubmitUriMetadata) GetUpdateTime added in v1.9.0

func (x *SubmitUriMetadata) GetUpdateTime() *timestamppb.Timestamp

func (*SubmitUriMetadata) ProtoMessage added in v1.9.0

func (*SubmitUriMetadata) ProtoMessage()

func (*SubmitUriMetadata) ProtoReflect added in v1.9.0

func (x *SubmitUriMetadata) ProtoReflect() protoreflect.Message

func (*SubmitUriMetadata) Reset added in v1.9.0

func (x *SubmitUriMetadata) Reset()

func (*SubmitUriMetadata) String added in v1.9.0

func (x *SubmitUriMetadata) String() string

type SubmitUriMetadata_State added in v1.9.0

type SubmitUriMetadata_State int32

Enum that represents the state of the long-running operation.

const (
	// Default unspecified state.
	SubmitUriMetadata_STATE_UNSPECIFIED SubmitUriMetadata_State = 0
	// The operation is currently running.
	SubmitUriMetadata_RUNNING SubmitUriMetadata_State = 1
	// The operation finished with a success status.
	SubmitUriMetadata_SUCCEEDED SubmitUriMetadata_State = 2
	// The operation was cancelled.
	SubmitUriMetadata_CANCELLED SubmitUriMetadata_State = 3
	// The operation finished with a failure status.
	SubmitUriMetadata_FAILED SubmitUriMetadata_State = 4
	// The operation was closed with no action taken.
	SubmitUriMetadata_CLOSED SubmitUriMetadata_State = 5
)

func (SubmitUriMetadata_State) Descriptor added in v1.9.0

func (SubmitUriMetadata_State) Enum added in v1.9.0

func (SubmitUriMetadata_State) EnumDescriptor deprecated added in v1.9.0

func (SubmitUriMetadata_State) EnumDescriptor() ([]byte, []int)

Deprecated: Use SubmitUriMetadata_State.Descriptor instead.

func (SubmitUriMetadata_State) Number added in v1.9.0

func (SubmitUriMetadata_State) String added in v1.9.0

func (x SubmitUriMetadata_State) String() string

func (SubmitUriMetadata_State) Type added in v1.9.0

type SubmitUriRequest added in v1.9.0

type SubmitUriRequest struct {

	// Required. The name of the project that is making the submission. This
	// string is in the format "projects/{project_number}".
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Required. The submission that contains the URI to be scanned.
	Submission *Submission `protobuf:"bytes,2,opt,name=submission,proto3" json:"submission,omitempty"`
	// Provides additional information about the submission.
	ThreatInfo *ThreatInfo `protobuf:"bytes,3,opt,name=threat_info,json=threatInfo,proto3" json:"threat_info,omitempty"`
	// Provides additional information about how the submission was discovered.
	ThreatDiscovery *ThreatDiscovery `protobuf:"bytes,4,opt,name=threat_discovery,json=threatDiscovery,proto3" json:"threat_discovery,omitempty"`
	// contains filtered or unexported fields
}

Request to send a potentially malicious URI to WebRisk.

func (*SubmitUriRequest) Descriptor deprecated added in v1.9.0

func (*SubmitUriRequest) Descriptor() ([]byte, []int)

Deprecated: Use SubmitUriRequest.ProtoReflect.Descriptor instead.

func (*SubmitUriRequest) GetParent added in v1.9.0

func (x *SubmitUriRequest) GetParent() string

func (*SubmitUriRequest) GetSubmission added in v1.9.0

func (x *SubmitUriRequest) GetSubmission() *Submission

func (*SubmitUriRequest) GetThreatDiscovery added in v1.9.0

func (x *SubmitUriRequest) GetThreatDiscovery() *ThreatDiscovery

func (*SubmitUriRequest) GetThreatInfo added in v1.9.0

func (x *SubmitUriRequest) GetThreatInfo() *ThreatInfo

func (*SubmitUriRequest) ProtoMessage added in v1.9.0

func (*SubmitUriRequest) ProtoMessage()

func (*SubmitUriRequest) ProtoReflect added in v1.9.0

func (x *SubmitUriRequest) ProtoReflect() protoreflect.Message

func (*SubmitUriRequest) Reset added in v1.9.0

func (x *SubmitUriRequest) Reset()

func (*SubmitUriRequest) String added in v1.9.0

func (x *SubmitUriRequest) String() string

type ThreatDiscovery added in v1.9.0

type ThreatDiscovery struct {

	// Platform on which the threat was discovered.
	Platform ThreatDiscovery_Platform `protobuf:"varint,1,opt,name=platform,proto3,enum=google.cloud.webrisk.v1.ThreatDiscovery_Platform" json:"platform,omitempty"`
	// CLDR region code of the countries/regions the URI poses a threat ordered
	// from most impact to least impact. Example: "US" for United States.
	RegionCodes []string `protobuf:"bytes,2,rep,name=region_codes,json=regionCodes,proto3" json:"region_codes,omitempty"`
	// contains filtered or unexported fields
}

Details about how the threat was discovered.

func (*ThreatDiscovery) Descriptor deprecated added in v1.9.0

func (*ThreatDiscovery) Descriptor() ([]byte, []int)

Deprecated: Use ThreatDiscovery.ProtoReflect.Descriptor instead.

func (*ThreatDiscovery) GetPlatform added in v1.9.0

func (x *ThreatDiscovery) GetPlatform() ThreatDiscovery_Platform

func (*ThreatDiscovery) GetRegionCodes added in v1.9.0

func (x *ThreatDiscovery) GetRegionCodes() []string

func (*ThreatDiscovery) ProtoMessage added in v1.9.0

func (*ThreatDiscovery) ProtoMessage()

func (*ThreatDiscovery) ProtoReflect added in v1.9.0

func (x *ThreatDiscovery) ProtoReflect() protoreflect.Message

func (*ThreatDiscovery) Reset added in v1.9.0

func (x *ThreatDiscovery) Reset()

func (*ThreatDiscovery) String added in v1.9.0

func (x *ThreatDiscovery) String() string

type ThreatDiscovery_Platform added in v1.9.0

type ThreatDiscovery_Platform int32

Platform types.

const (
	// Default.
	ThreatDiscovery_PLATFORM_UNSPECIFIED ThreatDiscovery_Platform = 0
	// General Android platform.
	ThreatDiscovery_ANDROID ThreatDiscovery_Platform = 1
	// General iOS platform.
	ThreatDiscovery_IOS ThreatDiscovery_Platform = 2
	// General macOS platform.
	ThreatDiscovery_MACOS ThreatDiscovery_Platform = 3
	// General Windows platform.
	ThreatDiscovery_WINDOWS ThreatDiscovery_Platform = 4
)

func (ThreatDiscovery_Platform) Descriptor added in v1.9.0

func (ThreatDiscovery_Platform) Enum added in v1.9.0

func (ThreatDiscovery_Platform) EnumDescriptor deprecated added in v1.9.0

func (ThreatDiscovery_Platform) EnumDescriptor() ([]byte, []int)

Deprecated: Use ThreatDiscovery_Platform.Descriptor instead.

func (ThreatDiscovery_Platform) Number added in v1.9.0

func (ThreatDiscovery_Platform) String added in v1.9.0

func (x ThreatDiscovery_Platform) String() string

func (ThreatDiscovery_Platform) Type added in v1.9.0

type ThreatEntryAdditions

type ThreatEntryAdditions struct {

	// The raw SHA256-formatted entries.
	// Repeated to allow returning sets of hashes with different prefix sizes.
	RawHashes []*RawHashes `protobuf:"bytes,1,rep,name=raw_hashes,json=rawHashes,proto3" json:"raw_hashes,omitempty"`
	// The encoded 4-byte prefixes of SHA256-formatted entries, using a
	// Golomb-Rice encoding. The hashes are converted to uint32, sorted in
	// ascending order, then delta encoded and stored as encoded_data.
	RiceHashes *RiceDeltaEncoding `protobuf:"bytes,2,opt,name=rice_hashes,json=riceHashes,proto3" json:"rice_hashes,omitempty"`
	// contains filtered or unexported fields
}

Contains the set of entries to add to a local database. May contain a combination of compressed and raw data in a single response.

func (*ThreatEntryAdditions) Descriptor deprecated

func (*ThreatEntryAdditions) Descriptor() ([]byte, []int)

Deprecated: Use ThreatEntryAdditions.ProtoReflect.Descriptor instead.

func (*ThreatEntryAdditions) GetRawHashes

func (x *ThreatEntryAdditions) GetRawHashes() []*RawHashes

func (*ThreatEntryAdditions) GetRiceHashes

func (x *ThreatEntryAdditions) GetRiceHashes() *RiceDeltaEncoding

func (*ThreatEntryAdditions) ProtoMessage

func (*ThreatEntryAdditions) ProtoMessage()

func (*ThreatEntryAdditions) ProtoReflect

func (x *ThreatEntryAdditions) ProtoReflect() protoreflect.Message

func (*ThreatEntryAdditions) Reset

func (x *ThreatEntryAdditions) Reset()

func (*ThreatEntryAdditions) String

func (x *ThreatEntryAdditions) String() string

type ThreatEntryRemovals

type ThreatEntryRemovals struct {

	// The raw removal indices for a local list.
	RawIndices *RawIndices `protobuf:"bytes,1,opt,name=raw_indices,json=rawIndices,proto3" json:"raw_indices,omitempty"`
	// The encoded local, lexicographically-sorted list indices, using a
	// Golomb-Rice encoding. Used for sending compressed removal indices. The
	// removal indices (uint32) are sorted in ascending order, then delta encoded
	// and stored as encoded_data.
	RiceIndices *RiceDeltaEncoding `protobuf:"bytes,2,opt,name=rice_indices,json=riceIndices,proto3" json:"rice_indices,omitempty"`
	// contains filtered or unexported fields
}

Contains the set of entries to remove from a local database.

func (*ThreatEntryRemovals) Descriptor deprecated

func (*ThreatEntryRemovals) Descriptor() ([]byte, []int)

Deprecated: Use ThreatEntryRemovals.ProtoReflect.Descriptor instead.

func (*ThreatEntryRemovals) GetRawIndices

func (x *ThreatEntryRemovals) GetRawIndices() *RawIndices

func (*ThreatEntryRemovals) GetRiceIndices

func (x *ThreatEntryRemovals) GetRiceIndices() *RiceDeltaEncoding

func (*ThreatEntryRemovals) ProtoMessage

func (*ThreatEntryRemovals) ProtoMessage()

func (*ThreatEntryRemovals) ProtoReflect

func (x *ThreatEntryRemovals) ProtoReflect() protoreflect.Message

func (*ThreatEntryRemovals) Reset

func (x *ThreatEntryRemovals) Reset()

func (*ThreatEntryRemovals) String

func (x *ThreatEntryRemovals) String() string

type ThreatInfo added in v1.9.0

type ThreatInfo struct {

	// The type of abuse.
	AbuseType ThreatInfo_AbuseType `` /* 139-byte string literal not displayed */
	// Confidence that the URI is unsafe.
	ThreatConfidence *ThreatInfo_Confidence `protobuf:"bytes,2,opt,name=threat_confidence,json=threatConfidence,proto3" json:"threat_confidence,omitempty"`
	// Context about why the URI is unsafe.
	ThreatJustification *ThreatInfo_ThreatJustification `protobuf:"bytes,3,opt,name=threat_justification,json=threatJustification,proto3" json:"threat_justification,omitempty"`
	// contains filtered or unexported fields
}

Context about the submission including the type of abuse found on the URI and supporting details.

func (*ThreatInfo) Descriptor deprecated added in v1.9.0

func (*ThreatInfo) Descriptor() ([]byte, []int)

Deprecated: Use ThreatInfo.ProtoReflect.Descriptor instead.

func (*ThreatInfo) GetAbuseType added in v1.9.0

func (x *ThreatInfo) GetAbuseType() ThreatInfo_AbuseType

func (*ThreatInfo) GetThreatConfidence added in v1.9.0

func (x *ThreatInfo) GetThreatConfidence() *ThreatInfo_Confidence

func (*ThreatInfo) GetThreatJustification added in v1.9.0

func (x *ThreatInfo) GetThreatJustification() *ThreatInfo_ThreatJustification

func (*ThreatInfo) ProtoMessage added in v1.9.0

func (*ThreatInfo) ProtoMessage()

func (*ThreatInfo) ProtoReflect added in v1.9.0

func (x *ThreatInfo) ProtoReflect() protoreflect.Message

func (*ThreatInfo) Reset added in v1.9.0

func (x *ThreatInfo) Reset()

func (*ThreatInfo) String added in v1.9.0

func (x *ThreatInfo) String() string

type ThreatInfo_AbuseType added in v1.9.0

type ThreatInfo_AbuseType int32

The abuse type found on the URI.

const (
	// Default.
	ThreatInfo_ABUSE_TYPE_UNSPECIFIED ThreatInfo_AbuseType = 0
	// The URI contains malware.
	ThreatInfo_MALWARE ThreatInfo_AbuseType = 1
	// The URI contains social engineering.
	ThreatInfo_SOCIAL_ENGINEERING ThreatInfo_AbuseType = 2
	// The URI contains unwanted software.
	ThreatInfo_UNWANTED_SOFTWARE ThreatInfo_AbuseType = 3
)

func (ThreatInfo_AbuseType) Descriptor added in v1.9.0

func (ThreatInfo_AbuseType) Enum added in v1.9.0

func (ThreatInfo_AbuseType) EnumDescriptor deprecated added in v1.9.0

func (ThreatInfo_AbuseType) EnumDescriptor() ([]byte, []int)

Deprecated: Use ThreatInfo_AbuseType.Descriptor instead.

func (ThreatInfo_AbuseType) Number added in v1.9.0

func (ThreatInfo_AbuseType) String added in v1.9.0

func (x ThreatInfo_AbuseType) String() string

func (ThreatInfo_AbuseType) Type added in v1.9.0

type ThreatInfo_Confidence added in v1.9.0

type ThreatInfo_Confidence struct {

	// Types that are valid to be assigned to Value:
	//
	//	*ThreatInfo_Confidence_Score
	//	*ThreatInfo_Confidence_Level
	Value isThreatInfo_Confidence_Value `protobuf_oneof:"value"`
	// contains filtered or unexported fields
}

Confidence that a URI is unsafe.

func (*ThreatInfo_Confidence) Descriptor deprecated added in v1.9.0

func (*ThreatInfo_Confidence) Descriptor() ([]byte, []int)

Deprecated: Use ThreatInfo_Confidence.ProtoReflect.Descriptor instead.

func (*ThreatInfo_Confidence) GetLevel added in v1.9.0

func (*ThreatInfo_Confidence) GetScore added in v1.9.0

func (x *ThreatInfo_Confidence) GetScore() float32

func (*ThreatInfo_Confidence) GetValue added in v1.9.0

func (x *ThreatInfo_Confidence) GetValue() isThreatInfo_Confidence_Value

func (*ThreatInfo_Confidence) ProtoMessage added in v1.9.0

func (*ThreatInfo_Confidence) ProtoMessage()

func (*ThreatInfo_Confidence) ProtoReflect added in v1.9.0

func (x *ThreatInfo_Confidence) ProtoReflect() protoreflect.Message

func (*ThreatInfo_Confidence) Reset added in v1.9.0

func (x *ThreatInfo_Confidence) Reset()

func (*ThreatInfo_Confidence) String added in v1.9.0

func (x *ThreatInfo_Confidence) String() string

type ThreatInfo_Confidence_ConfidenceLevel added in v1.9.0

type ThreatInfo_Confidence_ConfidenceLevel int32

Enum representation of confidence.

const (
	// Default.
	ThreatInfo_Confidence_CONFIDENCE_LEVEL_UNSPECIFIED ThreatInfo_Confidence_ConfidenceLevel = 0
	// Less than 60% confidence that the URI is unsafe.
	ThreatInfo_Confidence_LOW ThreatInfo_Confidence_ConfidenceLevel = 1
	// Between 60% and 80% confidence that the URI is unsafe.
	ThreatInfo_Confidence_MEDIUM ThreatInfo_Confidence_ConfidenceLevel = 2
	// Greater than 80% confidence that the URI is unsafe.
	ThreatInfo_Confidence_HIGH ThreatInfo_Confidence_ConfidenceLevel = 3
)

func (ThreatInfo_Confidence_ConfidenceLevel) Descriptor added in v1.9.0

func (ThreatInfo_Confidence_ConfidenceLevel) Enum added in v1.9.0

func (ThreatInfo_Confidence_ConfidenceLevel) EnumDescriptor deprecated added in v1.9.0

func (ThreatInfo_Confidence_ConfidenceLevel) EnumDescriptor() ([]byte, []int)

Deprecated: Use ThreatInfo_Confidence_ConfidenceLevel.Descriptor instead.

func (ThreatInfo_Confidence_ConfidenceLevel) Number added in v1.9.0

func (ThreatInfo_Confidence_ConfidenceLevel) String added in v1.9.0

func (ThreatInfo_Confidence_ConfidenceLevel) Type added in v1.9.0

type ThreatInfo_Confidence_Level added in v1.9.0

type ThreatInfo_Confidence_Level struct {
	// Enum representation of confidence.
	Level ThreatInfo_Confidence_ConfidenceLevel `protobuf:"varint,2,opt,name=level,proto3,enum=google.cloud.webrisk.v1.ThreatInfo_Confidence_ConfidenceLevel,oneof"`
}

type ThreatInfo_Confidence_Score added in v1.9.0

type ThreatInfo_Confidence_Score struct {
	// A decimal representation of confidence in the range of 0
	// to 1 where 0 indicates no confidence and 1 indicates
	// complete confidence.
	Score float32 `protobuf:"fixed32,1,opt,name=score,proto3,oneof"`
}

type ThreatInfo_ThreatJustification added in v1.9.0

type ThreatInfo_ThreatJustification struct {

	// Labels associated with this URI that explain how it was classified.
	Labels []ThreatInfo_ThreatJustification_JustificationLabel `` /* 152-byte string literal not displayed */
	// Free-form context on why this URI is unsafe.
	Comments []string `protobuf:"bytes,2,rep,name=comments,proto3" json:"comments,omitempty"`
	// contains filtered or unexported fields
}

Context about why the URI is unsafe.

func (*ThreatInfo_ThreatJustification) Descriptor deprecated added in v1.9.0

func (*ThreatInfo_ThreatJustification) Descriptor() ([]byte, []int)

Deprecated: Use ThreatInfo_ThreatJustification.ProtoReflect.Descriptor instead.

func (*ThreatInfo_ThreatJustification) GetComments added in v1.9.0

func (x *ThreatInfo_ThreatJustification) GetComments() []string

func (*ThreatInfo_ThreatJustification) GetLabels added in v1.9.0

func (*ThreatInfo_ThreatJustification) ProtoMessage added in v1.9.0

func (*ThreatInfo_ThreatJustification) ProtoMessage()

func (*ThreatInfo_ThreatJustification) ProtoReflect added in v1.9.0

func (*ThreatInfo_ThreatJustification) Reset added in v1.9.0

func (x *ThreatInfo_ThreatJustification) Reset()

func (*ThreatInfo_ThreatJustification) String added in v1.9.0

type ThreatInfo_ThreatJustification_JustificationLabel added in v1.9.0

type ThreatInfo_ThreatJustification_JustificationLabel int32

Labels that explain how the URI was classified.

const (
	// Default.
	ThreatInfo_ThreatJustification_JUSTIFICATION_LABEL_UNSPECIFIED ThreatInfo_ThreatJustification_JustificationLabel = 0
	// The submitter manually verified that the submission is unsafe.
	ThreatInfo_ThreatJustification_MANUAL_VERIFICATION ThreatInfo_ThreatJustification_JustificationLabel = 1
	// The submitter received the submission from an end user.
	ThreatInfo_ThreatJustification_USER_REPORT ThreatInfo_ThreatJustification_JustificationLabel = 2
	// The submitter received the submission from an automated system.
	ThreatInfo_ThreatJustification_AUTOMATED_REPORT ThreatInfo_ThreatJustification_JustificationLabel = 3
)

func (ThreatInfo_ThreatJustification_JustificationLabel) Descriptor added in v1.9.0

func (ThreatInfo_ThreatJustification_JustificationLabel) Enum added in v1.9.0

func (ThreatInfo_ThreatJustification_JustificationLabel) EnumDescriptor deprecated added in v1.9.0

Deprecated: Use ThreatInfo_ThreatJustification_JustificationLabel.Descriptor instead.

func (ThreatInfo_ThreatJustification_JustificationLabel) Number added in v1.9.0

func (ThreatInfo_ThreatJustification_JustificationLabel) String added in v1.9.0

func (ThreatInfo_ThreatJustification_JustificationLabel) Type added in v1.9.0

type ThreatType

type ThreatType int32

The type of threat. This maps directly to the threat list a threat may belong to.

const (
	// No entries should match this threat type. This threat type is unused.
	ThreatType_THREAT_TYPE_UNSPECIFIED ThreatType = 0
	// Malware targeting any platform.
	ThreatType_MALWARE ThreatType = 1
	// Social engineering targeting any platform.
	ThreatType_SOCIAL_ENGINEERING ThreatType = 2
	// Unwanted software targeting any platform.
	ThreatType_UNWANTED_SOFTWARE ThreatType = 3
	// A list of extended coverage social engineering URIs targeting any
	// platform.
	ThreatType_SOCIAL_ENGINEERING_EXTENDED_COVERAGE ThreatType = 4
)

func (ThreatType) Descriptor

func (ThreatType) Descriptor() protoreflect.EnumDescriptor

func (ThreatType) Enum

func (x ThreatType) Enum() *ThreatType

func (ThreatType) EnumDescriptor deprecated

func (ThreatType) EnumDescriptor() ([]byte, []int)

Deprecated: Use ThreatType.Descriptor instead.

func (ThreatType) Number

func (x ThreatType) Number() protoreflect.EnumNumber

func (ThreatType) String

func (x ThreatType) String() string

func (ThreatType) Type

type UnimplementedWebRiskServiceServer

type UnimplementedWebRiskServiceServer struct {
}

UnimplementedWebRiskServiceServer should be embedded to have forward compatible implementations.

func (UnimplementedWebRiskServiceServer) CreateSubmission

func (UnimplementedWebRiskServiceServer) SearchHashes

func (UnimplementedWebRiskServiceServer) SearchUris

func (UnimplementedWebRiskServiceServer) SubmitUri added in v1.9.0

type UnsafeWebRiskServiceServer added in v1.11.2

type UnsafeWebRiskServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeWebRiskServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to WebRiskServiceServer will result in compilation errors.

type WebRiskServiceClient

type WebRiskServiceClient interface {
	// Gets the most recent threat list diffs. These diffs should be applied to
	// a local database of hashes to keep it up-to-date. If the local database is
	// empty or excessively out-of-date, a complete snapshot of the database will
	// be returned. This Method only updates a single ThreatList at a time. To
	// update multiple ThreatList databases, this method needs to be called once
	// for each list.
	ComputeThreatListDiff(ctx context.Context, in *ComputeThreatListDiffRequest, opts ...grpc.CallOption) (*ComputeThreatListDiffResponse, error)
	// This method is used to check whether a URI is on a given threatList.
	// Multiple threatLists may be searched in a single query.
	// The response will list all requested threatLists the URI was found to
	// match. If the URI is not found on any of the requested ThreatList an
	// empty response will be returned.
	SearchUris(ctx context.Context, in *SearchUrisRequest, opts ...grpc.CallOption) (*SearchUrisResponse, error)
	// Gets the full hashes that match the requested hash prefix.
	// This is used after a hash prefix is looked up in a threatList
	// and there is a match. The client side threatList only holds partial hashes
	// so the client must query this method to determine if there is a full
	// hash match of a threat.
	SearchHashes(ctx context.Context, in *SearchHashesRequest, opts ...grpc.CallOption) (*SearchHashesResponse, error)
	// Creates a Submission of a URI suspected of containing phishing content to
	// be reviewed. If the result verifies the existence of malicious phishing
	// content, the site will be added to the [Google's Social Engineering
	// lists](https://support.google.com/webmasters/answer/6350487/) in order to
	// protect users that could get exposed to this threat in the future. Only
	// allowlisted projects can use this method during Early Access. Please reach
	// out to Sales or your customer engineer to obtain access.
	CreateSubmission(ctx context.Context, in *CreateSubmissionRequest, opts ...grpc.CallOption) (*Submission, error)
	// Submits a URI suspected of containing malicious content to be reviewed.
	// Returns a google.longrunning.Operation which, once the review is complete,
	// is updated with its result. You can use the [Pub/Sub API]
	// (https://cloud.google.com/pubsub) to receive notifications for the returned
	// Operation. If the result verifies the existence of malicious content, the
	// site will be added to the [Google's Social Engineering lists]
	// (https://support.google.com/webmasters/answer/6350487/) in order to
	// protect users that could get exposed to this threat in the future. Only
	// allowlisted projects can use this method during Early Access. Please reach
	// out to Sales or your customer engineer to obtain access.
	SubmitUri(ctx context.Context, in *SubmitUriRequest, opts ...grpc.CallOption) (*longrunningpb.Operation, error)
}

WebRiskServiceClient is the client API for WebRiskService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type WebRiskServiceServer

type WebRiskServiceServer interface {
	// Gets the most recent threat list diffs. These diffs should be applied to
	// a local database of hashes to keep it up-to-date. If the local database is
	// empty or excessively out-of-date, a complete snapshot of the database will
	// be returned. This Method only updates a single ThreatList at a time. To
	// update multiple ThreatList databases, this method needs to be called once
	// for each list.
	ComputeThreatListDiff(context.Context, *ComputeThreatListDiffRequest) (*ComputeThreatListDiffResponse, error)
	// This method is used to check whether a URI is on a given threatList.
	// Multiple threatLists may be searched in a single query.
	// The response will list all requested threatLists the URI was found to
	// match. If the URI is not found on any of the requested ThreatList an
	// empty response will be returned.
	SearchUris(context.Context, *SearchUrisRequest) (*SearchUrisResponse, error)
	// Gets the full hashes that match the requested hash prefix.
	// This is used after a hash prefix is looked up in a threatList
	// and there is a match. The client side threatList only holds partial hashes
	// so the client must query this method to determine if there is a full
	// hash match of a threat.
	SearchHashes(context.Context, *SearchHashesRequest) (*SearchHashesResponse, error)
	// Creates a Submission of a URI suspected of containing phishing content to
	// be reviewed. If the result verifies the existence of malicious phishing
	// content, the site will be added to the [Google's Social Engineering
	// lists](https://support.google.com/webmasters/answer/6350487/) in order to
	// protect users that could get exposed to this threat in the future. Only
	// allowlisted projects can use this method during Early Access. Please reach
	// out to Sales or your customer engineer to obtain access.
	CreateSubmission(context.Context, *CreateSubmissionRequest) (*Submission, error)
	// Submits a URI suspected of containing malicious content to be reviewed.
	// Returns a google.longrunning.Operation which, once the review is complete,
	// is updated with its result. You can use the [Pub/Sub API]
	// (https://cloud.google.com/pubsub) to receive notifications for the returned
	// Operation. If the result verifies the existence of malicious content, the
	// site will be added to the [Google's Social Engineering lists]
	// (https://support.google.com/webmasters/answer/6350487/) in order to
	// protect users that could get exposed to this threat in the future. Only
	// allowlisted projects can use this method during Early Access. Please reach
	// out to Sales or your customer engineer to obtain access.
	SubmitUri(context.Context, *SubmitUriRequest) (*longrunningpb.Operation, error)
}

WebRiskServiceServer is the server API for WebRiskService service. All implementations should embed UnimplementedWebRiskServiceServer for forward compatibility

Jump to